@@ -148,7 +148,8 @@ function(x, ...) {
 #	else getAllTerms.formula(f, intercept = intercept)
 #}
 
-split_formula_by_bar <- function(f) {
+split_formula_by_bar <-
+function(f) {
 	n <- length(f)
 	ans <- if(length(f[[n]]) != 1L && f[[n]][[1L]] == "|") {
 		f1 <- vector("list", 2L)
@@ -166,8 +167,9 @@ split_formula_by_bar <- function(f) {
 function(x, intercept = FALSE, ...) {
 
 	formList <- split_formula_by_bar(formula(x))
-	formList <- lapply(lapply(formList, terms.formula, data = eval(x$call$data)),
-		formula)
+	formList <- lapply(lapply(formList, terms.formula,
+		data = eval(x$call$data, environment(formula(x)))),
+			formula)
 	z <- lapply(formList, getAllTerms, intercept = TRUE)
 	
 	if(oneform <- length(formList) == 1L) z <- c(z, z)
