@@ -90,7 +90,7 @@ function (object, parm, level = 0.95, full = FALSE, ...) {
     ci <- t(sapply(parm, function(i)
 		par.avg(cf[,i], se[,i], wts, dfs[, i], alpha = a2)))[, 4L:5L, drop = FALSE]
 	ci[is.na(object$coefficients[1L, parm]), ] <- NA_real_
-    colnames(ci) <- getFrom("stats", "format.perc")(c(a, 1L - a), 3L)
+    colnames(ci) <- format.perc(c(a, 1L - a), 3L)
     return(ci)
 }
 
